@@ -16,7 +16,7 @@ fn test_metafits_context_new_invalid() {
     let metafits_filename = "invalid.metafits";
 
     // No gpubox files provided
-    let context = MetafitsContext::new(&metafits_filename, MWAVersion::CorrMWAXv2);
+    let context = MetafitsContext::new(&metafits_filename, Some(MWAVersion::CorrMWAXv2));
 
     assert!(context.is_err());
 }
@@ -30,7 +30,7 @@ fn test_metafits_context_new_vcslegacy_valid() {
     // Read the observation using mwalib
     //
     // Open a context and load in a test metafits
-    let context = MetafitsContext::new(&metafits_filename, MWAVersion::VCSLegacyRecombined)
+    let context = MetafitsContext::new(&metafits_filename, Some(MWAVersion::VCSLegacyRecombined))
         .expect("Failed to create MetafitsContext");
 
     // Test the properties of the context object match what we expect
@@ -51,7 +51,7 @@ fn test_metafits_context_new_corrlegacy_valid() {
     // Read the observation using mwalib
     //
     // Open a context and load in a test metafits
-    let context = MetafitsContext::new(&metafits_filename, MWAVersion::CorrLegacy)
+    let context = MetafitsContext::new(&metafits_filename, Some(MWAVersion::CorrLegacy))
         .expect("Failed to create MetafitsContext");
 
     // Test the properties of the context object match what we expect
@@ -232,7 +232,7 @@ fn test_metafits_context_new_vcsmwax2_valid() {
     // Read the observation using mwalib
     //
     // Open a context and load in a test metafits
-    let context = MetafitsContext::new(&metafits_filename, MWAVersion::VCSMWAXv2)
+    let context = MetafitsContext::new(&metafits_filename, Some(MWAVersion::VCSMWAXv2))
         .expect("Failed to create MetafitsContext");
 
     // Test the properties of the context object match what we expect
@@ -244,6 +244,33 @@ fn test_metafits_context_new_vcsmwax2_valid() {
     assert_eq!(context.num_volt_fine_chans_per_coarse, 1);
 }
 
+#[test]
+fn test_metafits_context_new_vcs_legacy_valid() {
+    // Open the test mwa v 1 metafits file
+    let metafits_filename = "test_files/1101503312_1_timestep/1101503312.metafits";
+
+    //
+    // Read the observation using mwalib
+    //
+    // Open a context and load in a test metafits
+    let context = MetafitsContext::new(&metafits_filename, Some(MWAVersion::VCSLegacyRecombined))
+        .expect("Failed to create MetafitsContext");
+
+    // rf_inputs:                [Tile104Y, ..., Tile055X],
+    assert_eq!(context.num_rf_inputs, 256);
+    assert_eq!(context.rf_inputs[0].pol, Pol::Y);
+    assert_eq!(context.rf_inputs[0].tile_name, "Tile104");
+    assert_eq!(context.rf_inputs[255].pol, Pol::X);
+    assert_eq!(context.rf_inputs[255].tile_name, "Tile055");
+
+    // Test the properties of the context object match what we expect
+    // antennas:                 [Tile011, Tile012, ... Tile167, Tile168],
+    // NOTE: since in Legacy VCS the VCS order may look like Tile104Y, Tile103Y, Tile102Y, Tile104X, ...
+    // so the order of antennas makes no sense, since 104 needs to be first AND further down the list!, so we leave it in the MWAX order.
+    assert_eq!(context.antennas[0].tile_name, "Tile011");
+    assert_eq!(context.antennas[127].tile_name, "Tile168");
+}
+
 #[test]
 fn test_populate_expected_timesteps() {
     // Note the timesteps returned are fully tested in the timesteps tests, so this is checking the metafits_context calling of that code
@@ -378,6 +405,79 @@ fn test_populate_expected_coarse_channels_corr_mwaxv2() {
     }
 }
 
+#[test]
+fn test_metafits_context_new_guess_version() {
+    // Open the test metafits file
+    let metafits_filename = "test_files/1101503312_1_timestep/1101503312.metafits";
+
+    // Open a context and load in a test metafits
+    let result = MetafitsContext::new(&metafits_filename, None);
+    assert!(result.is_ok());
+
+    let context = result.unwrap();
+    assert_eq!(context.mwa_version.unwrap(), MWAVersion::CorrLegacy);
+}
+
+#[test]
+fn test_generate_expected_volt_filename_legacy_vcs() {
+    // Open the test metafits file
+    let metafits_filename = "test_files/1101503312_1_timestep/1101503312.metafits";
+
+    // Open a context and load in a test metafits
+    let result = MetafitsContext::new(&metafits_filename, Some(MWAVersion::VCSLegacyRecombined));
+    assert!(result.is_ok());
+
+    let context = result.unwrap();
+    let result = context.generate_expected_volt_filename(3, 1);
+    assert!(result.is_ok());
+    let new_filename = result.unwrap();
+    assert_eq!(new_filename, "1101503312_1101503315_ch110.dat")
+}
+
+#[test]
+fn test_generate_expected_volt_filename_mwax_vcs() {
+    // Open the test metafits file
+    let metafits_filename = "test_files/1101503312_1_timestep/1101503312.metafits";
+
+    // Open a context and load in a test metafits
+    let result = MetafitsContext::new(&metafits_filename, Some(MWAVersion::VCSMWAXv2));
+    assert!(result.is_ok());
+
+    let context = result.unwrap();
+    let result = context.generate_expected_volt_filename(2, 1);
+    assert!(result.is_ok());
+    let new_filename = result.unwrap();
+    assert_eq!(new_filename, "1101503312_1101503328_110.sub")
+}
+
+#[test]
+fn test_generate_expected_volt_filename_invalid_timestep() {
+    // Open the test metafits file
+    let metafits_filename = "test_files/1101503312_1_timestep/1101503312.metafits";
+
+    // Open a context and load in a test metafits
+    let result = MetafitsContext::new(&metafits_filename, Some(MWAVersion::VCSLegacyRecombined));
+    assert!(result.is_ok());
+
+    let context = result.unwrap();
+    let result = context.generate_expected_volt_filename(99999, 0);
+    assert!(result.is_err());
+}
+
+#[test]
+fn test_generate_expected_volt_filename_invalid_coarse_chan() {
+    // Open the test metafits file
+    let metafits_filename = "test_files/1101503312_1_timestep/1101503312.metafits";
+
+    // Open a context and load in a test metafits
+    let result = MetafitsContext::new(&metafits_filename, Some(MWAVersion::VCSLegacyRecombined));
+    assert!(result.is_ok());
+
+    let context = result.unwrap();
+    let result = context.generate_expected_volt_filename(0, 99);
+    assert!(result.is_err());
+}
+
 #[test]
 fn test_mwa_version_display_corr_mwaxv2() {
     let cv = MWAVersion::CorrMWAXv2;
